@@ -7,11 +7,11 @@ If the directory 'cabal-dev/packages-X.X.X.conf' exists, add it to the
 options ghc-mod uses to check the source.  Otherwise just pass it on.
 -}
 
-import Data.Maybe             (listToMaybe)
-import System.FilePath.Find
-import System.FilePath.Posix  (splitPath,joinPath,(</>))
-import System.Posix.Directory (getWorkingDirectory)
+import Control.Applicative    ((<$>))
+import Data.List              (find)
+import System.FilePath        (splitPath,joinPath,(</>))
 import System.Directory
+import Text.Regex.Posix       ((=~))
 
 import Types
 
@@ -25,7 +25,7 @@ modifyOptions opts =
 
 findCabalDev :: IO (Maybe String)
 findCabalDev =
-  getWorkingDirectory >>= searchIt . splitPath
+  getCurrentDirectory >>= searchIt . splitPath
 
 addPath :: Options -> String -> Options
 addPath orig_opts path = do
@@ -37,9 +37,13 @@ searchIt [] = return Nothing
 searchIt path = do
   a <- doesDirectoryExist (mpath path)
   if a then do
-    b <- find always (fileName ~~? "packages*.conf") $ mpath path
-    maybe (searchIt $ init path) (return . Just) $ listToMaybe b
+    findConf (mpath path)
   else
-    return Nothing
+    searchIt $ init path
   where
     mpath a = joinPath a </> "cabal-dev/"
+
+findConf :: FilePath -> IO (Maybe FilePath)
+findConf path = do
+  f <- find (=~ "packages.*\\.conf") <$> getDirectoryContents path
+  return $ ((path </>) <$> f)
